.. _How_to_add_a_new_theme:

How to add a new theme
======================

Theme can be added manually by placing files in directories:

* Templates: ``apps/pages/templates/themes``
* Statics: ``mysmile/static/themes``

Switching between themes works by  :ref:`preferences <Preferences>`.
